summaryrefslogtreecommitdiffstats
path: root/kdat/VerifyOptDlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdat/VerifyOptDlg.h')
-rw-r--r--kdat/VerifyOptDlg.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kdat/VerifyOptDlg.h b/kdat/VerifyOptDlg.h
index faa94a7..5c3915a 100644
--- a/kdat/VerifyOptDlg.h
+++ b/kdat/VerifyOptDlg.h
@@ -46,10 +46,10 @@ public:
* @param def The default working directory.
* @param files The list of files that will be verified/restored.
* @param restore TRUE means we are doing a restore, FALSE means we are doing a verify.
* @param tqparent The tqparent widget for the dialog.
* @param name The name for the dialog.
*/
- VerifyOptDlg( const TQString & def, const TQStringList& files, bool restore = FALSE, TQWidget* tqparent = 0, const char* name = 0 );
+ VerifyOptDlg( const TQString & def, const TQStringList& files, bool restore = FALSE, TQWidget* parent = 0, const char* name = 0 );
/**
* Destroy the verify/restore options dialog.
@@ -46,10 +46,10 @@ public:
* @param files The list of files that will be verified/restored.
* @param restore TRUE means we are doing a restore, FALSE means we are doing a verify.
- * @param tqparent The tqparent widget for the dialog.
+ * @param parent The parent widget for the dialog.
* @param name The name for the dialog.
*/